@@ -11,4 +11,9 @@ def gpu():
     tf_version=tf.__version__
     gpu=tf.config.list_physical_devices('GPU')
     return f'TensorFlow:{tf_version}\nGPU nummber:{len(gpu)}\nGPU Info:{gpu}'
+
+def hi(name):
+
+    return f'Name:{name}'
 print(gpu())
+print(hi('james'))
